==> haskell-yesod-persistent-1.6.0.8-482-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-J9wOxrhHstyLkNcIYkqSoP
key:                  yesod-persistent-1.6.0.8-J9wOxrhHstyLkNcIYkqSoP
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  5801daad4dfc244a0993011bceb505b8
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-J9wOxrhHstyLkNcIYkqSoP
depends:
    base-4.17.2.1 blaze-builder-0.4.4.1-Cau0yAlxVeRBhqZO9aptGP
    conduit-1.3.6.1-LX1OqlTDVgXB5T9goEDWxI
    persistent-2.14.5.2-6F0Sk76LwbbKAFQeZZCR3Y
    resource-pool-0.2.3.2-Ialdc56ouwKEOPaqifHSOL
    resourcet-1.2.6-AJ1OoWHoMXT5AEQka8SZQl transformers-0.5.6.2
    yesod-core-1.6.27.1-ETiJYZFGA0j7ncfoHSySVt

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-483-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-Eg1qDoJcsXI5EBvnocWb7Q
key:                  yesod-persistent-1.6.0.8-Eg1qDoJcsXI5EBvnocWb7Q
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  da8e027259b78ec3e2e89f4e334706fb
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-Eg1qDoJcsXI5EBvnocWb7Q
depends:
    base-4.17.2.1 blaze-builder-0.4.4.1-Cau0yAlxVeRBhqZO9aptGP
    conduit-1.3.6.1-LX1OqlTDVgXB5T9goEDWxI
    persistent-2.14.5.2-EFwh713VBzoEXC9AExpOGQ
    resource-pool-0.2.3.2-Ialdc56ouwKEOPaqifHSOL
    resourcet-1.2.6-AJ1OoWHoMXT5AEQka8SZQl transformers-0.5.6.2
    yesod-core-1.6.27.1-AATcviqIZ5x7loyuqwCxSV

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
